/* =====================================================================
 * NetArduino for showing weather forecast and time from the internet
 * ---------------------------------------------------------------------
 * weatherdata.cpp
 *   handles storage, print and send of weather information
 * =====================================================================
 * By: Zakie Mashiah
 * =====================================================================
 * Copyright
 *  You may use this code with single condition of giving visible
 *  credit to the author.
 * =====================================================================
 * TODO
 * =====================================================================
 *  Revision History
 *      31-Oct-2011 v0.9
 * =====================================================================
 */

#ifndef __weatherdata_h
#define __weatherdata_h

#define MAX_DOW_NAME 10		// Maximum size for Day-Of-Week in forecast info
#define MAX_ICON_NAME 20	// Maximum size of icon file name (no path)
#define MAX_COND_NAME 20	// Maximum size of condition data
#define MAX_WIND_DATA 20	// Maximum size of Wind information
#define MAX_CITY_NAME 20	// Maximum size of city name
#define MAX_FORECAST_DAYS 5	// Maximum number of forecast days we store

typedef struct tagForecastConditions
{
	char 	dayOfWeek[MAX_DOW_NAME];
	int 	lowTemp;
	int 	highTemp;
	char 	icon[MAX_ICON_NAME];
	char 	condition[MAX_COND_NAME];
} ForecastConditionsStruct;

typedef struct tagCurrentConditions
{
	char 	condition[MAX_COND_NAME];
	int 	temp;
	int 	humidity;
	char 	icon[MAX_ICON_NAME];
	char 	wind[MAX_WIND_DATA];
} CurrentConditionsStruct;

typedef struct tagForecastInformation
{
	char 	city[MAX_CITY_NAME];
} ForecastInformationStruct;

typedef struct tagWeatherDataStruct
{
	ForecastInformationStruct	info;
	CurrentConditionsStruct 	curr;
	int 						forecastLen;
	ForecastConditionsStruct	forecast[MAX_FORECAST_DAYS];
} WeatherDataStruct;	// We could use this structure to easily communicate
						// the data in the future


class WeatherData
{
	private:
		void sendElement(char *e, int l);
		void sendMember(char part, char member, int num);
		void sendMember(char part, char member, char *str);
		void sendMember(char part, char member, int idx, int num);
		void sendMember(char part, char member, int idx, char *str);
	public:
		WeatherDataStruct data;	// TODO move to private

		void Reset();
		void StartForecast();
		void Print();
		void Send();
		void setCity(char *city);
		void setTempCurr(int temp);
		void setHumidCurr(int humidity);
		void setIconCurr(char *icon);
		void setWindCurr(char *wind);
		void setCondCurr(char *condition);
		void setDowFore(char *day);
		void setLowTempFore(int temp);
		void setHighTempFore(int temp);
		void setIconFore(char *icon);
		void setCondFore(char *condition);
		void addForecast();
};

#endif